local ModList

Def.ActorFrame {
	InitCommand: =>
		ModList = dofile ResolveRelativePath 'mods.lua', 1

		-- preferred modifiers
		for player=0, 1
			GAMESTATE\GetPlayerState(player)\SetPlayerOptions 'ModsLevel_Preferred', ModList.PreferredMods or '1x'

	OnCommand: =>
		@queuecommand 'ModReader'

	ModReaderCommand: =>
		-- table copier
		copy = (value) ->
			if type(value) ~= 'table'
				return value

			{ k,copy v for k,v in pairs value }

		-- preprocessing
		-- use a new table of mods for editing, keep the original preserved
		mods = {}
		for i=1, #ModList
			with mod = ModList[i]
				table.insert mods, mod

				-- any mods with an 'after', mark their start
				if not .start and .after
					.start = ModList[i - 1].start + .after

				-- insert repeated mods
				if .repeatUntil or .repeatTimes
					finish = .repeatUntil and .repeatUntil or .start + .repeatPeriod * (.repeatTimes - 1)
					for beat=.start, finish, .repeatPeriod
						repeatedMod = with copy mod
							.start = beat
							-- set these to nil so we don't recursively repeat them
							.repeatUntil = nil
							.repeatPeriod = nil

						table.insert mods, repeatedMod

		-- initialize any lua init calls
		for mod in *mods
			if mod.lua and mod.lua.init
				mod.lua\init!

		-- mark done any mods we've already passed
		-- in case we're doing this in edit mode
		for mod in *mods
			if GAMESTATE\GetSongBeat! > (mod.finish or mod.start + mod.len)
				mod.done = true

		@SetUpdateFunction (delta) =>
			curBeat = GAMESTATE\GetSongBeat!
			p1mods = { ModList.PreferredMods }
			p2mods = { ModList.PreferredMods }

			for mod in *mods do with mod
				if not .finish and .len
					.finish = .start + .len

				if curBeat >= .start and not .done
					if .mods
						table.insert p1mods, .mods if .player ~= PLAYER_2
						table.insert p2mods, .mods if .player ~= PLAYER_1

					if .lua
						if .luastarted and .lua.update
							pos = math.min 1, (curBeat - .start) / (.finish - .start)
							.lua\update mod, pos, delta

						-- here so that start and update aren't called in the same frame
						if .lua.start and not .luastarted
							.lua\start mod

						if not .luastarted then
							.luastarted = true

					if curBeat >= .finish
						.done = true
						if .lua and .lua.finish
							.lua\finish mod

			p1mods = table.concat p1mods, ','
			p2mods = table.concat p2mods, ','

			GAMESTATE\GetPlayerState(PLAYER_1)\SetPlayerOptions 'ModsLevel_Song', p1mods
			GAMESTATE\GetPlayerState(PLAYER_2)\SetPlayerOptions 'ModsLevel_Song', p2mods

			if modsDisplay = @GetChildren!.modsDisplay
				modsDisplay\settext "Player 1 Mods: #{p1mods}\nPlayer 2 Mods: #{p2mods}"

	-- for debug
	-- Def.BitmapText
	-- 	Name: 'modsDisplay'
	-- 	Font: 'Common Normal'
	-- 	OnCommand: =>
	-- 		@Center!
	-- 		@visible false -- set to true to show this

	-- keep background shown
	LoadActor(GAMESTATE\GetCurrentSong!\GetBackgroundPath!) .. {
		OnCommand: =>
			@Center!
			@scaletocover SCREEN_LEFT, SCREEN_TOP, SCREEN_RIGHT, SCREEN_BOTTOM
	}
}
