local applyToPlayers
applyToPlayers = function(func)
  local screen = SCREENMAN:GetTopScreen()
  for i = 1, 2 do
    do
      local field = screen:GetChild('PlayerP' .. i)
      if field then
        func(field, i)
      end
    end
  end
  do
    local children = screen:GetChild('')
    if children then
      for _index_0 = 1, #children do
        local child = children[_index_0]
        if tostring(child):find('Player') then
          func(child, 1)
        end
      end
    end
  end
end
local vibrate = {
  update = function(self, mod, pos)
    local mag = mod.magnitude or 50
    return applyToPlayers(function(self)
      self:vibrate()
      return self:effectmagnitude(mag, mag, 0)
    end)
  end,
  finish = function(self)
    return applyToPlayers(function(self)
      return self:stopeffect()
    end)
  end
}
local clock = {
  update = function(self, mod, pos)
    return applyToPlayers(function(self, pnum)
      return self:rotationz(math.min(pos * 1.33, 1) * 360 * (pnum == 1 and 1 or -1))
    end)
  end
}
local roll = {
  update = function(self, mod, pos)
    return applyToPlayers(function(self)
      return self:rotationx((pos ^ 0.5) * 360)
    end)
  end
}
local twirl = {
  update = function(self, mod, pos)
    return applyToPlayers(function(self)
      return self:rotationy(180 + (pos ^ 0.5) * 180)
    end)
  end
}
local mentalCollapse = {
  start = function(self)
    self.actorData = { }
    return SCREENMAN:GetTopScreen():RunCommandsOnChildren(function(child)
      do
        local _with_0 = child
        if not tostring(child):find('Player') then
          self.actorData[child] = {
            x = _with_0:GetX(),
            y = _with_0:GetY(),
            rotation = _with_0:GetRotationZ(),
            alpha = _with_0:GetDiffuseAlpha()
          }
          _with_0:accelerate(1)
          _with_0:diffusealpha(0)
          _with_0:rotationz(math.random(-10, 10))
          _with_0:addy(math.random(20, 50))
        end
        return _with_0
      end
    end)
  end,
  finish = function(self)
    return SCREENMAN:GetTopScreen():RunCommandsOnChildren(function(child)
      do
        local _with_0 = child
        do
          local data = self.actorData[child]
          if data then
            _with_0:stoptweening()
            _with_0:xy(data.x, data.y)
            _with_0:rotationz(data.rotation)
            _with_0:linear(1)
            _with_0:diffusealpha(data.alpha)
          end
        end
        return _with_0
      end
    end)
  end
}
local chaos = {
  update = function(self, mod, pos)
    local mag = (mod.magnitude or 10) * (1 - pos)
    do
      local _with_0 = SCREENMAN:GetTopScreen()
      _with_0:vibrate()
      _with_0:effectmagnitude(mag, mag, 0)
      return _with_0
    end
  end,
  finish = function(self)
    do
      local _with_0 = SCREENMAN:GetTopScreen()
      _with_0:stopeffect()
      return _with_0
    end
  end
}
local zoomoutin = {
  update = function(self, mod, pos)
    return applyToPlayers(function(self)
      return self:zoom(pos ^ 0.3)
    end)
  end
}
local ModList = {
  {
    start = 0,
    len = math.huge,
    mods = '*99 4x'
  },
  {
    start = 16,
    len = 1,
    lua = chaos
  },
  {
    start = 19.250,
    len = 1,
    lua = chaos
  },
  {
    start = 24,
    len = 1,
    lua = chaos
  },
  {
    start = 28,
    len = 1,
    lua = chaos
  },
  {
    start = 29.500,
    len = 1,
    lua = chaos
  },
  {
    start = 192,
    len = 2,
    lua = twirl
  },
  {
    start = 198,
    len = 2,
    lua = twirl
  },
  {
    start = 206,
    len = 2,
    lua = twirl
  },
  {
    start = 214,
    len = 2,
    lua = twirl
  },
  {
    start = 294,
    len = 6,
    lua = clock
  }
}
return ModList
