local applyToPlayers
applyToPlayers = function(func)
  local screen = SCREENMAN:GetTopScreen()
  for i = 1, 2 do
    do
      local field = screen:GetChild('PlayerP' .. i)
      if field then
        func(field, i)
      end
    end
  end
  do
    local children = screen:GetChild('')
    if children then
      for _index_0 = 1, #children do
        local child = children[_index_0]
        if tostring(child):find('Player') then
          func(child, 1)
        end
      end
    end
  end
end
local vibrate = {
  update = function(self, mod, pos)
    local mag = mod.magnitude or 50
    return applyToPlayers(function(self)
      self:vibrate()
      return self:effectmagnitude(mag, mag, 0)
    end)
  end,
  finish = function(self)
    return applyToPlayers(function(self)
      return self:stopeffect()
    end)
  end
}
local clock = {
  update = function(self, mod, pos)
    return applyToPlayers(function(self, pnum)
      return self:rotationz(math.min(pos * 1.33, 1) * 360 * (pnum == 1 and 1 or -1))
    end)
  end
}
local roll = {
  update = function(self, mod, pos)
    return applyToPlayers(function(self)
      return self:rotationx((pos ^ 0.5) * 360)
    end)
  end
}
local twirl = {
  update = function(self, mod, pos)
    return applyToPlayers(function(self)
      return self:rotationy(180 + (pos ^ 0.5) * 180)
    end)
  end
}
local mentalCollapse = {
  start = function(self)
    self.actorData = { }
    return SCREENMAN:GetTopScreen():RunCommandsOnChildren(function(child)
      do
        local _with_0 = child
        if not tostring(child):find('Player') then
          self.actorData[child] = {
            x = _with_0:GetX(),
            y = _with_0:GetY(),
            rotation = _with_0:GetRotationZ(),
            alpha = _with_0:GetDiffuseAlpha()
          }
          _with_0:accelerate(19)
          _with_0:diffusealpha(0)
          _with_0:rotationz(math.random(-10, 10))
          _with_0:addy(math.random(20, 50))
        end
        return _with_0
      end
    end)
  end,
  finish = function(self)
    return SCREENMAN:GetTopScreen():RunCommandsOnChildren(function(child)
      do
        local _with_0 = child
        do
          local data = self.actorData[child]
          if data then
            _with_0:stoptweening()
            _with_0:xy(data.x, data.y)
            _with_0:rotationz(data.rotation)
            _with_0:linear(1)
            _with_0:diffusealpha(data.alpha)
          end
        end
        return _with_0
      end
    end)
  end
}
local chaos = {
  update = function(self, mod, pos)
    local mag = (mod.magnitude or 10) * (1 - pos)
    do
      local _with_0 = SCREENMAN:GetTopScreen()
      _with_0:vibrate()
      _with_0:effectmagnitude(mag, mag, 0)
      return _with_0
    end
  end,
  finish = function(self)
    do
      local _with_0 = SCREENMAN:GetTopScreen()
      _with_0:stopeffect()
      return _with_0
    end
  end
}
local zoomoutin = {
  update = function(self, mod, pos)
    return applyToPlayers(function(self)
      return self:zoom(pos ^ 0.3)
    end)
  end
}
local ModList = {
  {
    start = 0,
    len = math.huge,
    mods = '4x'
  },
  {
    start = 0,
    finish = 110,
    mods = '*.08 50% drunk, *.05 30% tipsy, 20% dizzy'
  },
  {
    start = 0,
    finish = 48,
    mods = '20% stealth'
  },
  {
    start = 48,
    finish = 110,
    mods = '*.01 50% stealth'
  },
  {
    start = 47.5,
    len = 1,
    mods = '*999 beat'
  },
  {
    after = 1,
    len = 0,
    mods = '*999 no beat'
  },
  {
    start = 48,
    finish = 78,
    mods = '*1.5 no brake'
  },
  {
    start = 48,
    len = 0.1,
    mods = '*10 30% brake',
    repeatUntil = 77.5,
    repeatPeriod = 0.5
  },
  {
    start = 79.5,
    finish = 111.5,
    mods = '*999 beat'
  },
  {
    start = 111.5,
    len = 0,
    mods = '*999 no beat'
  },
  {
    start = 80,
    finish = 112,
    mods = '*6 no boost'
  },
  {
    after = 0,
    len = 0.7,
    mods = '*1.8 boost'
  },
  {
    after = 1,
    len = 0.7,
    mods = '*1.8 boost',
    repeatUntil = 109,
    repeatPeriod = 1
  },
  {
    start = 80,
    finish = 126,
    lua = mentalCollapse
  },
  {
    start = 110,
    finish = 120,
    mods = '*3 0.5x'
  },
  {
    start = 112,
    finish = 120,
    mods = '*0.375 200% centered'
  },
  {
    start = 112,
    finish = 120,
    mods = '*1.5 stealth'
  },
  {
    after = 0,
    len = 0,
    mods = '*999 50% stealth'
  },
  {
    after = 1.5,
    len = 0,
    mods = '*999 50% stealth',
    repeatTimes = 4,
    repeatPeriod = 2
  },
  {
    after = 0.5,
    len = 0,
    mods = '*999 50% stealth',
    repeatTimes = 4,
    repeatPeriod = 2
  },
  {
    start = 120,
    finish = 126.2,
    mods = '*0.6 200% mini, *10 100x'
  },
  {
    start = 126.2,
    finish = 128,
    mods = '*999 no mini, *999 4x, *999 dark'
  },
  {
    start = 126,
    len = 1,
    mods = '*999 stealth'
  },
  {
    start = 128 - 0.5,
    finish = 203.5,
    mods = '*999 500% beat'
  },
  {
    start = 203.5,
    len = 0,
    mods = '*999 no beat'
  },
  {
    start = 128,
    len = 1,
    lua = chaos,
    repeatTimes = 4,
    repeatPeriod = 1
  },
  {
    start = 135.25,
    len = 1,
    lua = chaos
  },
  {
    start = 136,
    len = 1,
    lua = chaos,
    repeatTimes = 4,
    repeatPeriod = 1
  },
  {
    start = 144,
    len = 1,
    lua = chaos,
    repeatTimes = 4,
    repeatPeriod = 1
  },
  {
    start = 152,
    len = 1,
    lua = chaos,
    repeatTimes = 4,
    repeatPeriod = 1
  },
  {
    start = 156,
    len = 1.5,
    lua = chaos
  },
  {
    start = 157.5,
    len = 1.5,
    lua = chaos
  },
  {
    start = 160,
    len = 1,
    lua = chaos,
    repeatTimes = 4,
    repeatPeriod = 1
  },
  {
    start = 167.25,
    len = 1,
    lua = chaos
  },
  {
    start = 168,
    len = 1,
    lua = chaos,
    repeatTimes = 3,
    repeatPeriod = 1
  },
  {
    start = 176,
    len = 1,
    lua = chaos,
    repeatTimes = 4,
    repeatPeriod = 1
  },
  {
    start = 184,
    len = 1,
    lua = chaos,
    repeatTimes = 8,
    repeatPeriod = 1
  },
  {
    start = 192,
    len = 0.5,
    lua = chaos,
    repeatTimes = 2,
    repeatPeriod = 0.5
  },
  {
    start = 193.5,
    len = 0.5,
    lua = chaos,
    repeatTimes = 2,
    repeatPeriod = 0.5
  },
  {
    start = 195,
    len = 3,
    lua = chaos
  },
  {
    start = 200,
    len = 0.5,
    lua = chaos,
    repeatTimes = 2,
    repeatPeriod = 0.5
  },
  {
    start = 201.5,
    len = 0.5,
    lua = chaos,
    repeatTimes = 2,
    repeatPeriod = 0.5
  },
  {
    start = 202,
    len = 1,
    lua = chaos
  },
  {
    start = 203,
    len = 8,
    lua = chaos
  },
  {
    start = 128,
    len = 4,
    mods = '*3.1 no centered'
  },
  {
    after = 0,
    len = 0,
    mods = '*999 -140% centered',
    repeatTimes = 4,
    repeatPeriod = 1
  },
  {
    start = 128,
    len = 4,
    mods = '*11 no tipsy, *11 no drunk'
  },
  {
    after = 0,
    len = 0,
    mods = '*999 500% tipsy, *999 500% drunk',
    repeatTimes = 2,
    repeatPeriod = 2
  },
  {
    after = 1,
    len = 0,
    mods = '*999 -500% tipsy, *999 -500% drunk',
    repeatTimes = 2,
    repeatPeriod = 2
  },
  {
    start = 128 - 0.01,
    len = 1,
    mods = '*999 invert'
  },
  {
    after = 1,
    len = 1,
    mods = '*999 flip, *999 -100% invert'
  },
  {
    after = 1,
    len = 1,
    mods = '*999 invert, *999 no flip'
  },
  {
    after = 1,
    len = 1,
    mods = '*999 no invert'
  },
  {
    start = 132.25,
    len = 0.5,
    mods = '*8 reverse'
  },
  {
    after = 0.5,
    len = 0.5,
    mods = '*8 flip, *8 reverse'
  },
  {
    after = 0.5,
    len = 0.5,
    mods = '*8 flip, *8 no reverse'
  },
  {
    after = 0.5,
    len = 0.5,
    mods = '*8 no flip, *8 no reverse'
  },
  {
    after = 0.5,
    len = 0.5,
    mods = '*8 no flip, *8 reverse'
  },
  {
    after = 0.5,
    len = 0.5,
    mods = '*8 no flip, *8 no reverse'
  },
  {
    start = 135.25,
    len = 1,
    mods = '*11 no tipsy, *11 no drunk'
  },
  {
    after = 0,
    len = 0,
    mods = '*999 -300% tipsy, *999 -300% drunk'
  },
  {
    start = 136,
    len = 4,
    mods = '*3.1 no centered'
  },
  {
    after = 0,
    len = 0,
    mods = '*999 -140% centered',
    repeatTimes = 4,
    repeatPeriod = 1
  },
  {
    start = 136,
    len = 4,
    mods = '*11 no tipsy, *11 no drunk'
  },
  {
    after = 0,
    len = 0,
    mods = '*999 500% tipsy, *999 500% drunk',
    repeatTimes = 2,
    repeatPeriod = 2
  },
  {
    after = 1,
    len = 0,
    mods = '*999 -500% tipsy, *999 -500% drunk',
    repeatTimes = 2,
    repeatPeriod = 2
  },
  {
    start = 136,
    len = 1,
    mods = '*999 invert'
  },
  {
    after = 1,
    len = 1,
    mods = '*999 flip, *999 -100% invert'
  },
  {
    after = 1,
    len = 1,
    mods = '*999 invert, *999 no flip'
  },
  {
    after = 1,
    len = 1,
    mods = '*999 no invert, *999 no flip'
  },
  {
    start = 140,
    len = 0.25,
    mods = '*10 300% tipsy'
  },
  {
    after = 0.5,
    len = 0.25,
    mods = '*20 -300% tipsy'
  },
  {
    after = 0.5,
    len = 0.25,
    mods = '*10 flip, *20 -300% tipsy'
  },
  {
    after = 0.5,
    len = 0.25,
    mods = '*10 flip, *20 300% tipsy'
  },
  {
    after = 0.5,
    len = 0.25,
    mods = '*10 no flip, *20 300% tipsy'
  },
  {
    after = 0.5,
    len = 0.25,
    mods = '*20 no tipsy'
  },
  {
    start = 143,
    len = 1,
    mods = '*4.5 no flip, *10 no tipsy',
    lua = vibrate,
    magnitude = 10
  },
  {
    after = 0,
    len = 0,
    mods = '*999 200% flip, *999 400% tipsy'
  },
  {
    start = 144,
    len = 4,
    mods = '*3.1 no centered'
  },
  {
    after = 0,
    len = 0,
    mods = '*999 -140% centered',
    repeatTimes = 4,
    repeatPeriod = 1
  },
  {
    start = 144,
    len = 4,
    mods = '*11 no tipsy, *11 no drunk'
  },
  {
    after = 0,
    len = 0,
    mods = '*999 500% tipsy, *999 500% drunk',
    repeatTimes = 2,
    repeatPeriod = 2
  },
  {
    after = 1,
    len = 0,
    mods = '*999 -500% tipsy, *999 -500% drunk',
    repeatTimes = 2,
    repeatPeriod = 2
  },
  {
    start = 144,
    len = 1,
    mods = '*999 flip, *999 -100% invert'
  },
  {
    after = 1,
    len = 1,
    mods = '*999 no flip, *999 invert'
  },
  {
    after = 1,
    len = 1,
    mods = '*999 invert, *999 no flip'
  },
  {
    after = 1,
    len = 1,
    mods = '*999 no invert, *999 no flip'
  },
  {
    start = 147,
    len = 1,
    mods = '50% stealth'
  },
  {
    start = 147.5,
    finish = 151,
    mods = '*5 50% mini'
  },
  {
    start = 147.5,
    finish = 151.5,
    mods = '*999 no beat'
  },
  {
    start = 148,
    finish = 152,
    mods = '*8 stealth'
  },
  {
    after = 0,
    len = 0,
    mods = '*999 50% stealth'
  },
  {
    after = 0.25,
    len = 0,
    mods = '*999 50% stealth'
  },
  {
    after = 0.25,
    len = 0,
    mods = '*999 50% stealth'
  },
  {
    start = 149,
    len = 0,
    mods = '*999 50% stealth'
  },
  {
    after = 0.25,
    len = 0,
    mods = '*999 50% stealth'
  },
  {
    start = 150 - 0.01,
    len = 0,
    mods = '*999 50% stealth'
  },
  {
    after = 0.125,
    len = 0,
    mods = '*999 50% stealth'
  },
  {
    after = 0.125,
    len = 0,
    mods = '*999 50% stealth'
  },
  {
    after = 0.25,
    len = 0,
    mods = '*999 50% stealth'
  },
  {
    after = 0.25,
    len = 0,
    mods = '*999 50% stealth'
  },
  {
    after = 0.25,
    len = 0,
    mods = '*999 50% stealth'
  },
  {
    after = 0.25,
    len = 0,
    mods = '*999 50% stealth'
  },
  {
    after = 0.25,
    len = 0,
    mods = '*999 50% stealth'
  },
  {
    after = 0.25,
    len = 0,
    mods = '*999 50% stealth'
  },
  {
    after = 0.25,
    len = 0,
    mods = '*999 50% stealth'
  },
  {
    start = 152,
    len = 4,
    mods = '*3.1 no centered'
  },
  {
    after = 0,
    len = 0,
    mods = '*999 -140% centered',
    repeatTimes = 4,
    repeatPeriod = 1
  },
  {
    start = 152,
    len = 4,
    mods = '*11 no tipsy, *11 no drunk'
  },
  {
    after = 0,
    len = 0,
    mods = '*999 500% tipsy, *999 500% drunk',
    repeatTimes = 2,
    repeatPeriod = 2
  },
  {
    after = 1,
    len = 0,
    mods = '*999 -500% tipsy, *999 -500% drunk',
    repeatTimes = 2,
    repeatPeriod = 2
  },
  {
    start = 152,
    len = 1,
    mods = '*999 no flip, *999 invert'
  },
  {
    after = 1,
    len = 1,
    mods = '*999 no flip, *999 invert'
  },
  {
    after = 1,
    len = 1,
    mods = '*999 no invert, *999 flip'
  },
  {
    after = 1,
    len = 1,
    mods = '*999 no invert, *999 no flip'
  },
  {
    start = 156,
    finish = 159,
    mods = '*999 no beat'
  },
  {
    start = 156,
    len = 1.5,
    lua = zoomoutin
  },
  {
    after = 1.5,
    len = 1.5,
    lua = zoomoutin
  },
  {
    start = 159,
    len = 1,
    lua = clock
  },
  {
    start = 160,
    len = 4,
    mods = '*3.1 no centered'
  },
  {
    after = 0,
    len = 0,
    mods = '*999 -140% centered',
    repeatTimes = 4,
    repeatPeriod = 1
  },
  {
    start = 160,
    len = 4,
    mods = '*11 no tipsy, *11 no drunk'
  },
  {
    after = 0,
    len = 0,
    mods = '*999 500% tipsy, *999 500% drunk',
    repeatTimes = 2,
    repeatPeriod = 2
  },
  {
    after = 1,
    len = 0,
    mods = '*999 -500% tipsy, *999 -500% drunk',
    repeatTimes = 2,
    repeatPeriod = 2
  },
  {
    start = 160,
    len = 1,
    mods = '*999 flip, *999 -100% invert'
  },
  {
    after = 1,
    len = 1,
    mods = '*999 no flip, *999 invert'
  },
  {
    after = 1,
    len = 1,
    mods = '*999 no flip, *999 invert'
  },
  {
    after = 1,
    len = 1,
    mods = '*999 no flip, *999 no invert'
  },
  {
    start = 167.25,
    len = 1,
    mods = '*11 no tipsy, *11 no drunk'
  },
  {
    after = 0,
    len = 0,
    mods = '*999 -300% tipsy, *999 -300% drunk'
  },
  {
    start = 152,
    len = 4,
    mods = '*3.1 no centered'
  },
  {
    after = 0,
    len = 0,
    mods = '*999 -140% centered',
    repeatTimes = 2,
    repeatPeriod = 1
  },
  {
    start = 164.25,
    len = 0.5,
    mods = '*8 reverse'
  },
  {
    after = 0.5,
    len = 0.5,
    mods = '*8 invert, *8 reverse'
  },
  {
    after = 0.5,
    len = 0.5,
    mods = '*8 invert, *8 no reverse'
  },
  {
    after = 0.5,
    len = 0.5,
    mods = '*8 no invert, *8 no reverse'
  },
  {
    after = 0.5,
    len = 0.5,
    mods = '*8 no invert, *8 reverse'
  },
  {
    after = 0.5,
    len = 0.5,
    mods = '*8 no invert, *8 no reverse'
  },
  {
    start = 168,
    len = 4,
    mods = '*11 no tipsy, *11 no drunk'
  },
  {
    after = 0,
    len = 0,
    mods = '*999 500% tipsy, *999 500% drunk'
  },
  {
    after = 1,
    len = 0,
    mods = '*999 -500% tipsy, *999 -500% drunk'
  },
  {
    after = 1,
    len = 0,
    mods = '*999 200% tipsy, *999 200% drunk'
  },
  {
    start = 168,
    len = 1,
    mods = '*999 no flip, *999 invert'
  },
  {
    after = 1,
    len = 1,
    mods = '*999 no flip, *999 invert'
  },
  {
    after = 1,
    len = 1,
    mods = '*999 no flip, *999 no invert'
  },
  {
    start = 170.25,
    len = 0.25,
    mods = '*20 flip'
  },
  {
    after = 0.25,
    len = 0.25,
    mods = '*20 no flip'
  },
  {
    start = 171,
    len = 0.75,
    lua = roll
  },
  {
    start = 172,
    len = 1,
    mods = '*3 no brake, *6.5 no dizzy'
  },
  {
    after = 0,
    len = 0,
    mods = '*9999 50% brake, *999 200% dizzy'
  },
  {
    after = 0.5,
    len = 0,
    mods = '*9999 50% brake, *999 -200% dizzy'
  },
  {
    start = 173,
    finish = 175,
    mods = '*8 stealth'
  },
  {
    after = 0,
    len = 0,
    mods = '*999 50% stealth'
  },
  {
    after = 0.25,
    len = 0,
    mods = '*999 50% stealth'
  },
  {
    after = 0.25,
    len = 0,
    mods = '*999 50% stealth'
  },
  {
    after = 0.25,
    len = 0,
    mods = '*999 50% stealth'
  },
  {
    after = 0.125,
    len = 0,
    mods = '*999 50% stealth'
  },
  {
    after = 0.125,
    len = 0,
    mods = '*999 50% stealth'
  },
  {
    after = 0.25,
    len = 0,
    mods = '*999 50% stealth'
  },
  {
    after = 0.25,
    len = 0,
    mods = '*999 50% stealth'
  },
  {
    after = 0.25,
    len = 0,
    mods = '*999 50% stealth'
  },
  {
    after = 0.25,
    len = 0,
    mods = '*999 50% stealth'
  },
  {
    start = 175,
    len = 0.75,
    lua = twirl
  },
  {
    start = 175,
    len = 1,
    lua = vibrate,
    magnitude = 20
  },
  {
    start = 176,
    len = 4,
    mods = '*3.1 no centered'
  },
  {
    after = 0,
    len = 0,
    mods = '*999 -140% centered',
    repeatTimes = 4,
    repeatPeriod = 1
  },
  {
    start = 176,
    len = 4,
    mods = '*11 no tipsy, *11 no drunk'
  },
  {
    after = 0,
    len = 0,
    mods = '*999 500% tipsy, *999 500% drunk',
    repeatTimes = 2,
    repeatPeriod = 2
  },
  {
    after = 1,
    len = 0,
    mods = '*999 -500% tipsy, *999 -500% drunk',
    repeatTimes = 2,
    repeatPeriod = 2
  },
  {
    start = 176,
    len = 1,
    mods = '*999 flip'
  },
  {
    after = 1,
    len = 1,
    mods = '*999 invert, *999 no flip'
  },
  {
    after = 1,
    len = 1,
    mods = '*999 75% flip, *999 -125% invert'
  },
  {
    after = 1,
    len = 1,
    mods = '*999 no flip, *999 no invert'
  },
  {
    start = 180,
    finish = 183,
    mods = '*999 mini, *999 70% drunk, *999 50% tipsy, *999 70% stealth'
  },
  {
    after = 3,
    len = 1,
    mods = '*1.5 no mini'
  },
  {
    start = 184,
    len = 8,
    mods = '*3.1 no centered'
  },
  {
    after = 0,
    len = 0,
    mods = '*999 -140% centered',
    repeatTimes = 8,
    repeatPeriod = 1
  },
  {
    start = 184,
    len = 8,
    mods = '*11 no tipsy, *11 no drunk'
  },
  {
    after = 0,
    len = 0,
    mods = '*999 500% tipsy, *999 500% drunk',
    repeatTimes = 4,
    repeatPeriod = 2
  },
  {
    after = 1,
    len = 0,
    mods = '*999 -500% tipsy, *999 -500% drunk',
    repeatTimes = 4,
    repeatPeriod = 2
  },
  {
    start = 184,
    len = 1,
    mods = '*999 flip, *999 no invert'
  },
  {
    after = 1,
    len = 1,
    mods = '*999 no flip, *999 invert'
  },
  {
    after = 1,
    len = 1,
    mods = '*999 flip, *999 -100% invert'
  },
  {
    after = 1,
    len = 1,
    mods = '*999 25% flip, *999 -75% invert'
  },
  {
    after = 1,
    len = 1,
    mods = '*999 flip, *999 no invert'
  },
  {
    after = 1,
    len = 1,
    mods = '*999 no flip, *999 no invert'
  },
  {
    start = 191.5,
    finish = 200.5,
    mods = '*999 no beat'
  },
  {
    start = 192,
    finish = 204,
    mods = '*11 no tipsy, *11 no drunk'
  },
  {
    start = 192,
    len = 0,
    mods = '*999 250% tipsy, *999 250% drunk'
  },
  {
    after = 0.5,
    len = 0,
    mods = '*999 -250% tipsy, *999 -250% drunk'
  },
  {
    start = 193,
    len = 0,
    mods = '*999 250% drunk'
  },
  {
    after = 0.25,
    len = 0,
    mods = '*999 -250% drunk'
  },
  {
    start = 193.5,
    len = 0,
    mods = '*999 250% tipsy, *999 250% drunk'
  },
  {
    after = 0.5,
    len = 0,
    mods = '*999 -250% tipsy, *999 -250% drunk'
  },
  {
    start = 194.5,
    len = 0,
    mods = '*999 250% drunk'
  },
  {
    after = 0.25,
    len = 0,
    mods = '*999 -250% drunk'
  },
  {
    start = 194.5,
    len = 1,
    mods = '*999 200% beat'
  },
  {
    start = 195,
    finish = 198.5,
    mods = '*1.5 4x'
  },
  {
    after = 0,
    len = 0,
    mods = '*999 0.3x'
  },
  {
    start = 198.5,
    len = 0,
    mods = '*999 200% drunk'
  },
  {
    after = 1 / 4,
    len = 0,
    mods = '*999 -200% drunk'
  },
  {
    after = 1 / 4,
    len = 0,
    mods = '*999 200% tipsy'
  },
  {
    after = 1 / 4,
    len = 0,
    mods = '*999 200% drunk'
  },
  {
    after = 1 / 4,
    len = 0,
    mods = '*999 -200% drunk'
  },
  {
    after = 1 / 8,
    len = 0,
    mods = '*999 200% tipsy'
  },
  {
    after = 1 / 8,
    len = 0,
    mods = '*999 -200% tipsy'
  },
  {
    start = 200,
    len = 0,
    mods = '*999 250% tipsy, *999 250% drunk'
  },
  {
    after = 0.5,
    len = 0,
    mods = '*999 -250% tipsy, *999 -250% drunk'
  },
  {
    start = 201,
    len = 0,
    mods = '*999 250% drunk'
  },
  {
    after = 0.25,
    len = 0,
    mods = '*999 -250% drunk'
  },
  {
    start = 201.5,
    len = 0,
    mods = '*999 250% tipsy, *999 250% drunk'
  },
  {
    after = 0.5,
    len = 0,
    mods = '*999 -500% tipsy, *999 -500% drunk'
  },
  {
    after = 1,
    len = 0,
    mods = '*999 500% tipsy, *999 500% drunk'
  },
  {
    start = 202,
    len = 1,
    mods = '*999 flip'
  },
  {
    after = 1,
    len = 1,
    mods = '*999 no flip'
  },
  {
    start = 203,
    len = math.huge,
    mods = '*999 invert, drunk, *0.15 stealth, *0.15 dark'
  },
  {
    after = 0.5,
    len = math.huge,
    mods = '50% tipsy'
  }
}
return ModList
