applyToPlayers = (func) ->
	screen = SCREENMAN\GetTopScreen!

	-- gameplay
	for i=1, 2
		if field = screen\GetChild 'PlayerP'..i
			func field, i

	-- editor (god knows why the playfield isn't named)
	if children = screen\GetChild ''
		for child in *children
			if tostring(child)\find'Player'
				func child, 1

vibrate =
	update: (mod, pos) =>
		mag = mod.magnitude or 50
		applyToPlayers =>
			@vibrate!
			@effectmagnitude mag, mag, 0

	finish: =>
		applyToPlayers =>
			@stopeffect!

clock =
	update: (mod, pos) =>
		applyToPlayers (pnum) =>
			@rotationz math.min(pos * 1.33, 1) * 360 * (pnum == 1 and 1 or -1)

roll =
	update: (mod, pos) =>
		applyToPlayers =>
			@rotationx (pos ^ 0.5) * 360

twirl =
	update: (mod, pos) =>
		applyToPlayers =>
			@rotationy 180 + (pos ^ 0.5) * 180

mentalCollapse =
	start: =>
		@actorData = {}
		SCREENMAN\GetTopScreen!\RunCommandsOnChildren (child) -> with child
			if not tostring(child)\find'Player'
				@actorData[child] =
					x: \GetX!
					y: \GetY!
					rotation: \GetRotationZ!
					alpha: \GetDiffuseAlpha!

				\accelerate 19
				\diffusealpha 0
				\rotationz math.random -10, 10
				\addy math.random 20, 50

	finish: =>
		SCREENMAN\GetTopScreen!\RunCommandsOnChildren (child) -> with child
			-- restore old properties
			if data = @actorData[child]
				\stoptweening!
				\xy data.x, data.y
				\rotationz data.rotation

				\linear 1
				\diffusealpha data.alpha

chaos =
	update: (mod, pos) =>
		mag = (mod.magnitude or 10) * (1 - pos)
		with SCREENMAN\GetTopScreen!
			\vibrate!
			\effectmagnitude mag, mag, 0

	finish: =>
		with SCREENMAN\GetTopScreen!
			\stopeffect!

zoomoutin =
	update: (mod, pos) =>
		applyToPlayers =>
			@zoom pos^0.3

ModList = {
	-- mod definition:
	-- {
	-- 	start:        <time mod should begin (in beats)>
	-- 	after:        <mod begins x beats after the previous one>
	-- 	finish:       <time mod should finish (in beats)>
	-- 	len:          <how long the mod lasts (in beats) (can leave out 'finish' if provided)>
	-- 	delay:        <how much the mod should be delayed before actually starting
	-- 	               this is useful for doing effects during stops>
	-- 	mods:         <a string of .crs format mods>
	-- 	lua:          <a lua function. it's given two arguments:
	-- 	               the first is 'pos', which is the positition
	-- 	               in time in the current mod
	-- 	               as in, if the mod is half done, pos will be 0.5
	-- 	               the second argument is the mod table itself
	-- 	               the last is a boolean, whether it's the last time the function is being called, 'done'>
	-- 	player:       <player to give the mods to, either PLAYER_1 or PLAYER_2,
	-- 	               will be both if left out>
	-- 	once:         <if true, will only make the lua function be run once,
	-- 	               instead of for the duration of the mod
	-- 	repeatPeriod: <beats between each repetition of the line>
	-- 	repeatUntil:  <will repeat the specified line until the specified beat>
	-- 	repeatTimes:  <will repeat the line a specified number of times>
	-- }

	{ start: 0, len: math.huge, mods: '4x' }

	{ start: 0, finish: 110, mods: '*.08 50% drunk, *.05 30% tipsy, 20% dizzy' }

	{ start: 0, finish: 48, mods: '20% stealth'}
	{ start: 48, finish: 110, mods: '*.01 50% stealth' }

	{ start: 47.5, len: 1, mods: '*999 beat' }
	{ after: 1, len: 0, mods: '*999 no beat' }

	{ start: 48, finish: 78, mods: '*1.5 no brake' }
	{ start: 48, len: 0.1, mods: '*10 30% brake', repeatUntil: 77.5, repeatPeriod: 0.5 }

	{ start: 79.5, finish: 111.5, mods: '*999 beat' }
	{ start: 111.5, len: 0, mods: '*999 no beat'}

	{ start: 80, finish: 112, mods: '*6 no boost' }
	{ after: 0, len: 0.7, mods: '*1.8 boost' }
	{ after: 1, len: 0.7, mods: '*1.8 boost', repeatUntil: 109, repeatPeriod: 1 }

	{ start: 80, finish: 126, lua: mentalCollapse }

	{ start: 110, finish: 120, mods: '*3 0.5x'}
	{ start: 112, finish: 120, mods: '*0.375 200% centered'}

	{ start: 112, finish: 120, mods: '*1.5 stealth'}
	{ after: 0, len: 0, mods: '*999 50% stealth' }
	{ after: 1.5, len: 0, mods: '*999 50% stealth', repeatTimes: 4, repeatPeriod: 2 }
	{ after: 0.5, len: 0, mods: '*999 50% stealth', repeatTimes: 4, repeatPeriod: 2 }

	{ start: 120, finish: 126.2, mods: '*0.6 200% mini, *10 100x' }
	{ start: 126.2, finish: 128, mods: '*999 no mini, *999 4x, *999 dark'}

	{ start: 126, len: 1, mods: '*999 stealth' }

	{ start: 128 - 0.5, finish: 203.5, mods: '*999 500% beat' }
	{ start: 203.5, len: 0, mods: '*999 no beat'}

	-- DEEEAAAH, DEEEAAH, DEEAAAH, DEEEAAAH
	{ start: 128, len: 1, lua: chaos, repeatTimes: 4, repeatPeriod: 1 }
	{ start: 135.25, len: 1, lua: chaos }

	{ start: 136, len: 1, lua: chaos, repeatTimes: 4, repeatPeriod: 1 }

	{ start: 144, len: 1, lua: chaos, repeatTimes: 4, repeatPeriod: 1 }
	{ start: 152, len: 1, lua: chaos, repeatTimes: 4, repeatPeriod: 1 }
	{ start: 156, len: 1.5, lua: chaos }
	{ start: 157.5, len: 1.5, lua: chaos }

	{ start: 160, len: 1, lua: chaos, repeatTimes: 4, repeatPeriod: 1 }
	{ start: 167.25, len: 1, lua: chaos }

	{ start: 168, len: 1, lua: chaos, repeatTimes: 3, repeatPeriod: 1 }
	{ start: 176, len: 1, lua: chaos, repeatTimes: 4, repeatPeriod: 1 }
	{ start: 184, len: 1, lua: chaos, repeatTimes: 8, repeatPeriod: 1 }

	{ start: 192, len: 0.5, lua: chaos, repeatTimes: 2, repeatPeriod: 0.5 }
	{ start: 193.5, len: 0.5, lua: chaos, repeatTimes: 2, repeatPeriod: 0.5 }
	{ start: 195, len: 3, lua: chaos }

	{ start: 200, len: 0.5, lua: chaos, repeatTimes: 2, repeatPeriod: 0.5 }
	{ start: 201.5, len: 0.5, lua: chaos, repeatTimes: 2, repeatPeriod: 0.5 }
	{ start: 202, len: 1, lua: chaos }
	{ start: 203, len: 8, lua: chaos }


	{ start: 128, len: 4, mods: '*3.1 no centered' }
	{ after: 0, len: 0, mods: '*999 -140% centered', repeatTimes: 4, repeatPeriod: 1 }

	{ start: 128, len: 4, mods: '*11 no tipsy, *11 no drunk' }
	{ after: 0, len: 0, mods: '*999 500% tipsy, *999 500% drunk', repeatTimes: 2, repeatPeriod: 2 }
	{ after: 1, len: 0, mods: '*999 -500% tipsy, *999 -500% drunk', repeatTimes: 2, repeatPeriod: 2 }

	{ start: 128 - 0.01, len: 1, mods: '*999 invert' }
	{ after: 1, len: 1, mods: '*999 flip, *999 -100% invert' }
	{ after: 1, len: 1, mods: '*999 invert, *999 no flip' }
	{ after: 1, len: 1, mods: '*999 no invert' }


	{ start: 132.25, len: 0.5, mods: '*8 reverse' }
	{ after: 0.5, len: 0.5, mods: '*8 flip, *8 reverse' }
	{ after: 0.5, len: 0.5, mods: '*8 flip, *8 no reverse' }
	{ after: 0.5, len: 0.5, mods: '*8 no flip, *8 no reverse' }
	{ after: 0.5, len: 0.5, mods: '*8 no flip, *8 reverse' }
	{ after: 0.5, len: 0.5, mods: '*8 no flip, *8 no reverse' }


	{ start: 135.25, len: 1, mods: '*11 no tipsy, *11 no drunk' }
	{ after: 0, len: 0, mods: '*999 -300% tipsy, *999 -300% drunk' }

	{ start: 136, len: 4, mods: '*3.1 no centered' }
	{ after: 0, len: 0, mods: '*999 -140% centered', repeatTimes: 4, repeatPeriod: 1 }

	{ start: 136, len: 4, mods: '*11 no tipsy, *11 no drunk' }
	{ after: 0, len: 0, mods: '*999 500% tipsy, *999 500% drunk', repeatTimes: 2, repeatPeriod: 2 }
	{ after: 1, len: 0, mods: '*999 -500% tipsy, *999 -500% drunk', repeatTimes: 2, repeatPeriod: 2 }

	{ start: 136, len: 1, mods: '*999 invert' }
	{ after: 1, len: 1, mods: '*999 flip, *999 -100% invert' }
	{ after: 1, len: 1, mods: '*999 invert, *999 no flip' }
	{ after: 1, len: 1, mods: '*999 no invert, *999 no flip' }


	{ start: 140, len: 0.25, mods: '*10 300% tipsy' }
	{ after: 0.5, len: 0.25, mods: '*20 -300% tipsy' }
	{ after: 0.5, len: 0.25, mods: '*10 flip, *20 -300% tipsy' }
	{ after: 0.5, len: 0.25, mods: '*10 flip, *20 300% tipsy' }
	{ after: 0.5, len: 0.25, mods: '*10 no flip, *20 300% tipsy' }
	{ after: 0.5, len: 0.25, mods: '*20 no tipsy' }

	{ start: 143, len: 1, mods: '*4.5 no flip, *10 no tipsy', lua: vibrate, magnitude: 10 }
	{ after: 0, len: 0, mods: '*999 200% flip, *999 400% tipsy'}


	{ start: 144, len: 4, mods: '*3.1 no centered' }
	{ after: 0, len: 0, mods: '*999 -140% centered', repeatTimes: 4, repeatPeriod: 1 }

	{ start: 144, len: 4, mods: '*11 no tipsy, *11 no drunk' }
	{ after: 0, len: 0, mods: '*999 500% tipsy, *999 500% drunk', repeatTimes: 2, repeatPeriod: 2 }
	{ after: 1, len: 0, mods: '*999 -500% tipsy, *999 -500% drunk', repeatTimes: 2, repeatPeriod: 2 }

	{ start: 144, len: 1, mods: '*999 flip, *999 -100% invert' }
	{ after: 1, len: 1, mods: '*999 no flip, *999 invert' }
	{ after: 1, len: 1, mods: '*999 invert, *999 no flip' }
	{ after: 1, len: 1, mods: '*999 no invert, *999 no flip' }


	{ start: 147, len: 1, mods: '50% stealth'}
	{ start: 147.5, finish: 151, mods: '*5 50% mini'}
	{ start: 147.5, finish: 151.5, mods: '*999 no beat'}

	{ start: 148, finish: 152, mods: '*8 stealth' }
	{ after: 0, len: 0, mods: '*999 50% stealth' }
	{ after: 0.25, len: 0, mods: '*999 50% stealth' }
	{ after: 0.25, len: 0, mods: '*999 50% stealth' }
	{ start: 149, len: 0, mods: '*999 50% stealth' }
	{ after: 0.25, len: 0, mods: '*999 50% stealth' }
	{ start: 150 - 0.01, len: 0, mods: '*999 50% stealth' }
	{ after: 0.125, len: 0, mods: '*999 50% stealth' }
	{ after: 0.125, len: 0, mods: '*999 50% stealth' }
	{ after: 0.25, len: 0, mods: '*999 50% stealth' }
	{ after: 0.25, len: 0, mods: '*999 50% stealth' }
	{ after: 0.25, len: 0, mods: '*999 50% stealth' }
	{ after: 0.25, len: 0, mods: '*999 50% stealth' }
	{ after: 0.25, len: 0, mods: '*999 50% stealth' }
	{ after: 0.25, len: 0, mods: '*999 50% stealth' }
	{ after: 0.25, len: 0, mods: '*999 50% stealth' }


	{ start: 152, len: 4, mods: '*3.1 no centered' }
	{ after: 0, len: 0, mods: '*999 -140% centered', repeatTimes: 4, repeatPeriod: 1 }

	{ start: 152, len: 4, mods: '*11 no tipsy, *11 no drunk' }
	{ after: 0, len: 0, mods: '*999 500% tipsy, *999 500% drunk', repeatTimes: 2, repeatPeriod: 2 }
	{ after: 1, len: 0, mods: '*999 -500% tipsy, *999 -500% drunk', repeatTimes: 2, repeatPeriod: 2 }

	{ start: 152, len: 1, mods: '*999 no flip, *999 invert' }
	{ after: 1, len: 1, mods: '*999 no flip, *999 invert' }
	{ after: 1, len: 1, mods: '*999 no invert, *999 flip' }
	{ after: 1, len: 1, mods: '*999 no invert, *999 no flip' }


	{ start: 156, finish: 159, mods: '*999 no beat' }

	{ start: 156, len: 1.5, lua: zoomoutin }
	{ after: 1.5, len: 1.5, lua: zoomoutin }

	{ start: 159, len: 1, lua: clock }


	{ start: 160, len: 4, mods: '*3.1 no centered' }
	{ after: 0, len: 0, mods: '*999 -140% centered', repeatTimes: 4, repeatPeriod: 1 }

	{ start: 160, len: 4, mods: '*11 no tipsy, *11 no drunk' }
	{ after: 0, len: 0, mods: '*999 500% tipsy, *999 500% drunk', repeatTimes: 2, repeatPeriod: 2 }
	{ after: 1, len: 0, mods: '*999 -500% tipsy, *999 -500% drunk', repeatTimes: 2, repeatPeriod: 2 }

	{ start: 160, len: 1, mods: '*999 flip, *999 -100% invert' }
	{ after: 1, len: 1, mods: '*999 no flip, *999 invert' }
	{ after: 1, len: 1, mods: '*999 no flip, *999 invert' }
	{ after: 1, len: 1, mods: '*999 no flip, *999 no invert' }


	{ start: 167.25, len: 1, mods: '*11 no tipsy, *11 no drunk' }
	{ after: 0, len: 0, mods: '*999 -300% tipsy, *999 -300% drunk' }

	{ start: 152, len: 4, mods: '*3.1 no centered' }
	{ after: 0, len: 0, mods: '*999 -140% centered', repeatTimes: 2, repeatPeriod: 1 }


	{ start: 164.25, len: 0.5, mods: '*8 reverse' }
	{ after: 0.5, len: 0.5, mods: '*8 invert, *8 reverse' }
	{ after: 0.5, len: 0.5, mods: '*8 invert, *8 no reverse' }
	{ after: 0.5, len: 0.5, mods: '*8 no invert, *8 no reverse' }
	{ after: 0.5, len: 0.5, mods: '*8 no invert, *8 reverse' }
	{ after: 0.5, len: 0.5, mods: '*8 no invert, *8 no reverse' }


	{ start: 168, len: 4, mods: '*11 no tipsy, *11 no drunk' }
	{ after: 0, len: 0, mods: '*999 500% tipsy, *999 500% drunk' }
	{ after: 1, len: 0, mods: '*999 -500% tipsy, *999 -500% drunk' }
	{ after: 1, len: 0, mods: '*999 200% tipsy, *999 200% drunk' }

	{ start: 168, len: 1, mods: '*999 no flip, *999 invert' }
	{ after: 1, len: 1, mods: '*999 no flip, *999 invert' }
	{ after: 1, len: 1, mods: '*999 no flip, *999 no invert'}

	{ start: 170.25, len: 0.25, mods: '*20 flip' }
	{ after: 0.25, len: 0.25, mods: '*20 no flip' }

	{ start: 171, len: 0.75, lua: roll }

	{ start: 172, len: 1, mods: '*3 no brake, *6.5 no dizzy' }
	{ after: 0, len: 0, mods: '*9999 50% brake, *999 200% dizzy' }
	{ after: 0.5, len: 0, mods: '*9999 50% brake, *999 -200% dizzy' }

	{ start: 173, finish: 175, mods: '*8 stealth' }
	{ after: 0, len: 0, mods: '*999 50% stealth' }
	{ after: 0.25, len: 0, mods: '*999 50% stealth' }
	{ after: 0.25, len: 0, mods: '*999 50% stealth' }
	{ after: 0.25, len: 0, mods: '*999 50% stealth' }
	{ after: 0.125, len: 0, mods: '*999 50% stealth' }
	{ after: 0.125, len: 0, mods: '*999 50% stealth' }
	{ after: 0.25, len: 0, mods: '*999 50% stealth' }
	{ after: 0.25, len: 0, mods: '*999 50% stealth' }
	{ after: 0.25, len: 0, mods: '*999 50% stealth' }
	{ after: 0.25, len: 0, mods: '*999 50% stealth' }

	{ start: 175, len: 0.75, lua: twirl }
	{ start: 175, len: 1, lua: vibrate, magnitude: 20 }

	{ start: 176, len: 4, mods: '*3.1 no centered' }
	{ after: 0, len: 0, mods: '*999 -140% centered', repeatTimes: 4, repeatPeriod: 1 }

	{ start: 176, len: 4, mods: '*11 no tipsy, *11 no drunk' }
	{ after: 0, len: 0, mods: '*999 500% tipsy, *999 500% drunk', repeatTimes: 2, repeatPeriod: 2 }
	{ after: 1, len: 0, mods: '*999 -500% tipsy, *999 -500% drunk', repeatTimes: 2, repeatPeriod: 2 }

	{ start: 176, len: 1, mods: '*999 flip' }
	{ after: 1, len: 1, mods: '*999 invert, *999 no flip' }
	{ after: 1, len: 1, mods: '*999 75% flip, *999 -125% invert' }
	{ after: 1, len: 1, mods: '*999 no flip, *999 no invert' }


	{ start: 180, finish: 183, mods: '*999 mini, *999 70% drunk, *999 50% tipsy, *999 70% stealth'}
	{ after: 3, len: 1, mods: '*1.5 no mini'}


	{ start: 184, len: 8, mods: '*3.1 no centered' }
	{ after: 0, len: 0, mods: '*999 -140% centered', repeatTimes: 8, repeatPeriod: 1 }

	{ start: 184, len: 8, mods: '*11 no tipsy, *11 no drunk' }
	{ after: 0, len: 0, mods: '*999 500% tipsy, *999 500% drunk', repeatTimes: 4, repeatPeriod: 2 }
	{ after: 1, len: 0, mods: '*999 -500% tipsy, *999 -500% drunk', repeatTimes: 4, repeatPeriod: 2 }

	{ start: 184, len: 1, mods: '*999 flip, *999 no invert' }
	{ after: 1, len: 1, mods: '*999 no flip, *999 invert' }
	{ after: 1, len: 1, mods: '*999 flip, *999 -100% invert' }
	{ after: 1, len: 1, mods: '*999 25% flip, *999 -75% invert' }
	{ after: 1, len: 1, mods: '*999 flip, *999 no invert' }
	{ after: 1, len: 1, mods: '*999 no flip, *999 no invert' }

	{ start: 191.5, finish: 200.5, mods: '*999 no beat' }

	{ start: 192, finish: 204, mods: '*11 no tipsy, *11 no drunk' }

	{ start: 192, len: 0, mods: '*999 250% tipsy, *999 250% drunk' }
	{ after: 0.5, len: 0, mods: '*999 -250% tipsy, *999 -250% drunk' }

	{ start: 193, len: 0, mods: '*999 250% drunk' }
	{ after: 0.25, len: 0, mods: '*999 -250% drunk' }

	{ start: 193.5, len: 0, mods: '*999 250% tipsy, *999 250% drunk' }
	{ after: 0.5, len: 0, mods: '*999 -250% tipsy, *999 -250% drunk' }

	{ start: 194.5, len: 0, mods: '*999 250% drunk' }
	{ after: 0.25, len: 0, mods: '*999 -250% drunk' }

	{ start: 194.5, len: 1, mods: '*999 200% beat'}

	{ start: 195, finish: 198.5, mods: '*1.5 4x'}
	{ after: 0, len: 0, mods: '*999 0.3x'}

	{ start: 198.5, len: 0, mods: '*999 200% drunk' }
	{ after: 1/4, len: 0, mods: '*999 -200% drunk' }
	{ after: 1/4, len: 0, mods: '*999 200% tipsy' }
	{ after: 1/4, len: 0, mods: '*999 200% drunk' }
	{ after: 1/4, len: 0, mods: '*999 -200% drunk' }
	{ after: 1/8, len: 0, mods: '*999 200% tipsy' }
	{ after: 1/8, len: 0, mods: '*999 -200% tipsy' }

	{ start: 200, len: 0, mods: '*999 250% tipsy, *999 250% drunk' }
	{ after: 0.5, len: 0, mods: '*999 -250% tipsy, *999 -250% drunk' }

	{ start: 201, len: 0, mods: '*999 250% drunk' }
	{ after: 0.25, len: 0, mods: '*999 -250% drunk' }

	{ start: 201.5, len: 0, mods: '*999 250% tipsy, *999 250% drunk' }
	{ after: 0.5, len: 0, mods: '*999 -500% tipsy, *999 -500% drunk' }
	{ after: 1, len: 0, mods: '*999 500% tipsy, *999 500% drunk' }

	{ start: 202, len: 1, mods: '*999 flip' }
	{ after: 1, len: 1, mods: '*999 no flip'}

	{ start: 203, len: math.huge, mods: '*999 invert, drunk, *0.15 stealth, *0.15 dark' }
	{ after: 0.5, len: math.huge, mods: '50% tipsy'}
}

return ModList
